######################################### DO NOT EDIT! #########################################
#### This file is automatically generated from data-raw/2-generate_r_code_from_containers.R ####
################################################################################################

#' @title pseudogp
#' 
#' @description
#' Will generate a trajectory using
#' [pseudogp](https://doi.org/10.1371/journal.pcbi.1005212).
#' 
#' This method was wrapped inside a
#' [container](https://github.com/dynverse/ti_pseudogp).
#' The original code of this method is available
#' [here](https://github.com/kieranrcampbell/pseudogp).
#' 
#' @references Campbell, K.R., Yau, C., 2016. Order Under Uncertainty: Robust
#' Differential Expression Analysis Using Probabilistic Models for Pseudotime
#' Inference. PLOS Computational Biology 12, e1005212.
#' 
#' @param smoothing_alpha The hyperparameter for the Gamma distribution that
#' controls arc-length. Domain: U(1, 20). Default: 10. Format: numeric.
#' @param smoothing_beta The hyperparameter for the Gamma distribution that
#' controls arc-length. Domain: U(1, 20). Default: 3. Format: numeric.
#' @param pseudotime_mean The mean of the constrained normal prior on the
#' pseudotimes. Domain: U(0, 1). Default: 0.5. Format: numeric.
#' @param pseudotime_var The variance of the constrained normal prior on the
#' pseudotimes. Domain: U(0.01, 1). Default: 1. Format: numeric.
#' @param chains The number of chains for the MCMC trace. Domain: U(1, 20).
#' Default: 3. Format: integer.
#' @param iter The number of iterations for the MCMC trace. Domain: e^U(4.61,
#' 6.91). Default: 100. Format: integer.
#' @param dimreds A character vector specifying which dimensionality reduction
#' methods to use. See `dyndimred::dimred()` for the list of available
#' dimensionality reduction methods. Domain: all subsets of {pca, mds, tsne, ica,
#' lle, landmark_mds, mds_sammon, mds_isomds, mds_smacof, umap, dm_diffusionmap,
#' dm_destiny}. Default: {pca, mds}. Format: subset.
#' @param initialise_from How to initialise the MCMC chain. One of "random" (stan
#' decides),"principal_curve", or "pca" (the first component of PCA rescaled is
#' taken to be the pseudotimes).Note: if multiple representations are provided,
#' `pseudogp` will take the principal curve orpca from the first rather than
#' combining them. If a particular representation is required, it isup to the user
#' to re-order them. Domain: {random, principal_curve, pca}. Default: random.
#' Format: character.
#' 
#' @keywords method
#' 
#' @return A TI method wrapper to be used together with
#' \code{\link[dynwrap:infer_trajectories]{infer_trajectory}}
#' @export
ti_pseudogp <- function(
    smoothing_alpha = 10,
    smoothing_beta = 3,
    pseudotime_mean = 0.5,
    pseudotime_var = 1,
    chains = 3L,
    iter = 100L,
    dimreds = c("pca", "mds"),
    initialise_from = "random"
) {
  create_ti_method_container(container_id = "dynverse/ti_pseudogp:v0.9.9.01")(
    smoothing_alpha = smoothing_alpha,
    smoothing_beta = smoothing_beta,
    pseudotime_mean = pseudotime_mean,
    pseudotime_var = pseudotime_var,
    chains = chains,
    iter = iter,
    dimreds = dimreds,
    initialise_from = initialise_from
  )
}

