% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ti_slice.R
\name{ti_slice}
\alias{ti_slice}
\title{SLICE}
\usage{
ti_slice(lm.method = "clustering", model.type = "tree",
  ss.method = "all", ss.threshold = 0.25,
  community.method = "louvain", cluster.method = "kmeans", k = 0L,
  k.max = 10L, B = 100L, k.opt.method = "firstmax")
}
\arguments{
\item{lm.method}{Select "clustering" based or "graph" based method to infer
lineage model. Domain: {clustering, graph}. Default: clustering. Format:
character.}

\item{model.type}{The type of models that will be infered: "tree" - directed
minimum spanning tree based, "graph" - directed graph based. Domain: {tree,
graph}. Default: tree. Format: character.}

\item{ss.method}{The method for defining core cell set for stable state
detection: all - all the cells in a cluster constitute the core cell set; top -
cells with scEntropy lower than the ss.threshold quantile of all the values in
a cluster constitute the core cell set; pcst - cells with scEntropy lower than
the ss.threshold quantile of all the values in a cluster constitute the prize
nodes, linear prize-collecting steiner tree algorithm is used to approximate an
optimal subnetwork, the cells in the subnetwork constitute the core cell set.
Stable states are defined as the centroids of the core cell sets. Domain: {all,
top, pcst}. Default: all. Format: character.}

\item{ss.threshold}{The threshold used when ss.method is "top" or "pcst".
Default: 0.25. Domain: U(0, 1). Default: 0.25. Format: numeric.}

\item{community.method}{The method for network community detection. Most of the
community detection methods implemented in the igraph package are supported,
including "fast_greedy", "edge_betweenness", "label_prop",
"leading_eigen","louvain","spinglass", "walktrap". If this parameter is set to
"auto", the algorithm will perform all the community detection methods and
select the one that generates the communities with best modularity. Only take
effect when lm.method is "graph". Domain: {fast_greedy, edge_betweenness,
label_prop, leading_eigen, louvain, spinglass, walktrap, auto}. Default:
louvain. Format: character.}

\item{cluster.method}{Use "kmeans" or "pam" to divide cells into clusters. Only
take effect when lm.method is "clustering". Domain: {kmeans, pam}. Default:
kmeans. Format: character.}

\item{k}{The number of cell clusters. If NULL, Gap statistic will be used to
determine an optimal k. Domain: U(0, 20). Default: 0. Format: integer.}

\item{k.max}{The "k.max" parameter of cluster::clusGap(); used when k is NULL.
Domain: U(3, 20). Default: 10. Format: integer.}

\item{B}{The "B" parameter of cluster::clusGap(); used when k is NULL. Domain:
U(3, 500). Default: 100. Format: integer.}

\item{k.opt.method}{The "method" parameter of cluster::maxSE(); used when k is
NULL. Domain: {firstmax, globalmax, Tibs2001SEmax, firstSEmax, globalSEmax}.
Default: firstmax. Format: character.}
}
\value{
A TI method wrapper to be used together with
\code{\link[dynwrap:infer_trajectories]{infer_trajectory}}
}
\description{
Will generate a trajectory using \href{https://doi.org/10.1093/nar/gkw1278}{SLICE}.

This method was wrapped inside a
\href{https://github.com/dynverse/ti_slice}{container}.
The original code of this method is available
\href{https://research.cchmc.org/pbge/slice.html}{here}.
}
\references{
Guo, M., Bao, E.L., Wagner, M., Whitsett, J.A., Xu, Y., 2016.
SLICE: determining cell differentiation and lineage based on single cell
entropy. Nucleic Acids Research gkw1278.
}
\keyword{method}
