
<!-- README.md is generated from README.Rmd. Please edit that file -->

<a href="https://travis-ci.org/dynverse/dynmethods"><img src="https://travis-ci.org/dynverse/dynmethods.svg" align="left"></a>
[**ℹ️ Tutorials**](https://dynverse.org)     [**ℹ️ Reference
documentation**](https://dynverse.org/reference/dynmethods)
<br><img src="man/figures/logo.png" align="right" />

# A collection of 55 trajectory inference methods

This package contains wrappers for trajectory inference (TI) methods.
The output of each method is transformed into a common trajectory model
using [dynwrap](https://www.github.com/dynverse/dynwrap), which allows
easy [visualisation and
comparison](https://www.github.com/dynverse/dyno). All methods are
wrapped inside a docker container, which avoids dependency issues, and
also makes it easy to add a new method.

**To run any of these methods, interpret the results and visualise the
trajectory, see the [dyno
package](https://www.github.com/dynverse/dyno).**

To include your own method, feel free to send us a [pull
request](https://github.com/dynverse/dynmethods/pulls) or create an
[issue](https://github.com/dynverse/dynmethods/labels/new%20method). The
easiest way to add a new method is [through a docker
container](https://dynverse.github.io/dynwrap/articles/create_ti_method_docker.html),
so that dependencies don’t pose any issues for other users, but we also
welcome methods [directly wrapped inside of
R](https://dynverse.github.io/dynwrap/articles/create_ti_method_r.html).
The main benefit of adding your own method is that users can easily
compare your method with others and [visualise/interpret the
output](https://www.github.com/dynverse/dyno). Moreover, your method
will be compared to other methods within [the TI method
evaluation](https://doi.org/10.1101/276907).

## List of included methods

| Method              | Doi                                                                                                             | Code                                                       | Docker                                                                                                                                     | Status                                                                                                                                            | Authors                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| :------------------ | :-------------------------------------------------------------------------------------------------------------- | :--------------------------------------------------------- | :----------------------------------------------------------------------------------------------------------------------------------------- | :------------------------------------------------------------------------------------------------------------------------------------------------ | :--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Angle               |                                                                                                                 | [code](https://github.com/dynverse/ti_angle)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.02-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_angle)               | [![Build status](https://travis-ci.org/dynverse/ti_angle.svg?branch=master)](https://travis-ci.org/dynverse/ti_angle)                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| CALISTA             | <a href='https://doi.org/10.1101/257550'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_calista)             | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_calista)             | [![Build status](https://travis-ci.org/dynverse/ti_calista.svg?branch=master)](https://travis-ci.org/dynverse/ti_calista)                         | <sub>Nan Papili Gao <a href='https://github.com/nanp'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| CellRouter          | <a href='https://doi.org/10.1038/s41467-018-03214-y'><img src='man/figures/doi_logo.png' height='16'></a>       | [code](https://github.com/dynverse/ti_cellrouter)          | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_cellrouter)          | [![Build status](https://travis-ci.org/dynverse/ti_cellrouter.svg?branch=master)](https://travis-ci.org/dynverse/ti_cellrouter)                   | <sub>Edroaldo Lummertz da Rocha <a href='https://orcid.org/0000-0003-0537-4223'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/edroaldo'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>James J. Collins <a href='https://orcid.org/0000-0003-0537-4223'><img src='man/figures/orcid_logo.svg' height='16'></a></sub><br><sub>George Q. Daley</sub>                                                                                                                                                                           |
| CellTrails          | <a href='https://doi.org/10.1016/j.celrep.2018.05.002'><img src='man/figures/doi_logo.png' height='16'></a>     | [code](https://github.com/dynverse/ti_celltrails)          | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_celltrails)          | [![Build status](https://travis-ci.org/dynverse/ti_celltrails.svg?branch=master)](https://travis-ci.org/dynverse/ti_celltrails)                   | <sub>Daniel Ellwanger <a href='https://github.com/dcellwanger'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| cellTree Gibbs      | <a href='https://doi.org/10.1186/s12859-016-1175-6'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_celltree_gibbs)      | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_celltree_gibbs)      | [![Build status](https://travis-ci.org/dynverse/ti_celltree_gibbs.svg?branch=master)](https://travis-ci.org/dynverse/ti_celltree_gibbs)           | <sub>David duVerle <a href='https://orcid.org/0000-0003-2836-0502'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/david-duverle'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Koji Tsuda <a href='https://orcid.org/0000-0002-4288-1606'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/tsudalab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                         |
| cellTree maptpx     | <a href='https://doi.org/10.1186/s12859-016-1175-6'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_celltree_maptpx)     | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_celltree_maptpx)     | [![Build status](https://travis-ci.org/dynverse/ti_celltree_maptpx.svg?branch=master)](https://travis-ci.org/dynverse/ti_celltree_maptpx)         | <sub>David duVerle <a href='https://orcid.org/0000-0003-2836-0502'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/david-duverle'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Koji Tsuda <a href='https://orcid.org/0000-0002-4288-1606'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/tsudalab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                         |
| cellTree vem        | <a href='https://doi.org/10.1186/s12859-016-1175-6'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_celltree_vem)        | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_celltree_vem)        | [![Build status](https://travis-ci.org/dynverse/ti_celltree_vem.svg?branch=master)](https://travis-ci.org/dynverse/ti_celltree_vem)               | <sub>David duVerle <a href='https://orcid.org/0000-0003-2836-0502'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/david-duverle'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Koji Tsuda <a href='https://orcid.org/0000-0002-4288-1606'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/tsudalab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                         |
| Component 1         |                                                                                                                 | [code](https://github.com/dynverse/ti_comp1)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_comp1)               | [![Build status](https://travis-ci.org/dynverse/ti_comp1.svg?branch=master)](https://travis-ci.org/dynverse/ti_comp1)                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| DPT                 | <a href='https://doi.org/10.1038/nmeth.3971'><img src='man/figures/doi_logo.png' height='16'></a>               | [code](https://github.com/dynverse/ti_dpt)                 | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_dpt)                 | [![Build status](https://travis-ci.org/dynverse/ti_dpt.svg?branch=master)](https://travis-ci.org/dynverse/ti_dpt)                                 | <sub>Laleh Haghverdi</sub><br><sub>Philipp Angerer <a href='https://orcid.org/0000-0002-0369-2888'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/flying-sheep'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Fabian Theis <a href='https://orcid.org/0000-0002-2419-1943'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/theislab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                        |
| ElPiGraph           |                                                                                                                 | [code](https://github.com/dynverse/ti_elpigraph)           | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_elpigraph)           | [![Build status](https://travis-ci.org/dynverse/ti_elpigraph.svg?branch=master)](https://travis-ci.org/dynverse/ti_elpigraph)                     | <sub>Luca Albergante <a href='https://orcid.org/0000-0001-8151-6989'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/Albluca'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                           |
| ElPiGraph - Cycle   |                                                                                                                 | [code](https://github.com/dynverse/ti_elpicycle)           | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_elpicycle)           | [![Build status](https://travis-ci.org/dynverse/ti_elpicycle.svg?branch=master)](https://travis-ci.org/dynverse/ti_elpicycle)                     | <sub>Luca Albergante <a href='https://orcid.org/0000-0001-8151-6989'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/Albluca'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                           |
| ElPiGraph - Linear  |                                                                                                                 | [code](https://github.com/dynverse/ti_elpilinear)          | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_elpilinear)          | [![Build status](https://travis-ci.org/dynverse/ti_elpilinear.svg?branch=master)](https://travis-ci.org/dynverse/ti_elpilinear)                   | <sub>Luca Albergante <a href='https://orcid.org/0000-0001-8151-6989'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/Albluca'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                           |
| Embeddr             | <a href='https://doi.org/10.1101/027219'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_embeddr)             | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_embeddr)             | [![Build status](https://travis-ci.org/dynverse/ti_embeddr.svg?branch=master)](https://travis-ci.org/dynverse/ti_embeddr)                         | <sub>Kieran Campbell <a href='https://github.com/kieranrcampbell'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| FateID              | <a href='https://doi.org/10.1038/nmeth.4662'><img src='man/figures/doi_logo.png' height='16'></a>               | [code](https://github.com/dynverse/ti_fateid)              | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_fateid)              | [![Build status](https://travis-ci.org/dynverse/ti_fateid.svg?branch=master)](https://travis-ci.org/dynverse/ti_fateid)                           | <sub>Dominic Grün <a href='https://github.com/dgrun'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| FORKS               | <a href='https://doi.org/10.1101/132811'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_forks)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_forks)               | [![Build status](https://travis-ci.org/dynverse/ti_forks.svg?branch=master)](https://travis-ci.org/dynverse/ti_forks)                             | <sub>Mayank Sharma <a href='https://github.com/macsharma'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| GNG                 |                                                                                                                 | [code](https://github.com/dynverse/ti_gng)                 | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_gng)                 | [![Build status](https://travis-ci.org/dynverse/ti_gng.svg?branch=master)](https://travis-ci.org/dynverse/ti_gng)                                 | <sub>Robrecht Cannoodt <a href='https://orcid.org/0000-0003-3641-729X'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/rcannood'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                        |
| GPfates             | <a href='https://doi.org/10.1126/sciimmunol.aal2192'><img src='man/figures/doi_logo.png' height='16'></a>       | [code](https://github.com/dynverse/ti_gpfates)             | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_gpfates)             | [![Build status](https://travis-ci.org/dynverse/ti_gpfates.svg?branch=master)](https://travis-ci.org/dynverse/ti_gpfates)                         | <sub>Valentine Svensson <a href='https://orcid.org/0000-0002-9217-2330'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/vals'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Sarah A. Teichmann <a href='https://orcid.org/0000-0002-6294-6366'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/Teichlab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                     |
| GrandPrix           | <a href='https://doi.org/10.1101/227843'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_grandprix)           | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_grandprix)           | [![Build status](https://travis-ci.org/dynverse/ti_grandprix.svg?branch=master)](https://travis-ci.org/dynverse/ti_grandprix)                     | <sub>Sumon Ahmed <a href='https://github.com/sumonahmedUoM'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| MATCHER             | <a href='https://doi.org/10.1186/s13059-017-1269-0'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_matcher)             | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_matcher)             | [![Build status](https://travis-ci.org/dynverse/ti_matcher.svg?branch=master)](https://travis-ci.org/dynverse/ti_matcher)                         | <sub>Joshua Welch <a href='https://github.com/jw156605'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Jan Prins</sub>                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| MERLoT              | <a href='https://doi.org/10.1101/261768'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_merlot)              | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_merlot)              | [![Build status](https://travis-ci.org/dynverse/ti_merlot.svg?branch=master)](https://travis-ci.org/dynverse/ti_merlot)                           | <sub>Gonzalo Parra <a href='https://orcid.org/0000-0003-2446-016X'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/gonzaparra'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Johannes Söding <a href='https://orcid.org/0000-0001-9642-8244'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/soedinglab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                     |
| MFA                 | <a href='https://doi.org/10.12688/wellcomeopenres.11087.1'><img src='man/figures/doi_logo.png' height='16'></a> | [code](https://github.com/dynverse/ti_mfa)                 | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_mfa)                 | [![Build status](https://travis-ci.org/dynverse/ti_mfa.svg?branch=master)](https://travis-ci.org/dynverse/ti_mfa)                                 | <sub>Kieran Campbell <a href='https://github.com/kieranrcampbell'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Christopher Yau <a href='https://orcid.org/0000-0001-7615-8523'><img src='man/figures/orcid_logo.svg' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                     |
| Monocle DDRTree     | <a href='https://doi.org/10.1038/nmeth.4402'><img src='man/figures/doi_logo.png' height='16'></a>               | [code](https://github.com/dynverse/ti_monocle_ddrtree)     | [![Version](https://img.shields.io/badge/Docker-v0.9.9.02-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_monocle_ddrtree)     | [![Build status](https://travis-ci.org/dynverse/ti_monocle_ddrtree.svg?branch=master)](https://travis-ci.org/dynverse/ti_monocle_ddrtree)         | <sub>Xiaojie Qiu <a href='https://github.com/Xiaojieqiu'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Cole Trapnell <a href='https://orcid.org/0000-0002-8105-4347'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/ctrapnell'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                 |
| Monocle ICA         | <a href='https://doi.org/10.1038/nmeth.4402'><img src='man/figures/doi_logo.png' height='16'></a>               | [code](https://github.com/dynverse/ti_monocle_ica)         | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_monocle_ica)         | [![Build status](https://travis-ci.org/dynverse/ti_monocle_ica.svg?branch=master)](https://travis-ci.org/dynverse/ti_monocle_ica)                 | <sub>Xiaojie Qiu <a href='https://github.com/Xiaojieqiu'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Cole Trapnell <a href='https://orcid.org/0000-0002-8105-4347'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/ctrapnell'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                 |
| Mpath               | <a href='https://doi.org/10.1038/ncomms11988'><img src='man/figures/doi_logo.png' height='16'></a>              | [code](https://github.com/dynverse/ti_mpath)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_mpath)               | [![Build status](https://travis-ci.org/dynverse/ti_mpath.svg?branch=master)](https://travis-ci.org/dynverse/ti_mpath)                             | <sub>Michael Poidinger <a href='https://orcid.org/0000-0002-1047-2277'><img src='man/figures/orcid_logo.svg' height='16'></a></sub><br><sub>Jinmiao Chen <a href='https://orcid.org/0000-0001-7547-6423'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/jinmiaochen'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                   |
| MST                 |                                                                                                                 | [code](https://github.com/dynverse/ti_mst)                 | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_mst)                 | [![Build status](https://travis-ci.org/dynverse/ti_mst.svg?branch=master)](https://travis-ci.org/dynverse/ti_mst)                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| ouija               | <a href='https://doi.org/10.1101/060442'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_ouija)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_ouija)               | [![Build status](https://travis-ci.org/dynverse/ti_ouija.svg?branch=master)](https://travis-ci.org/dynverse/ti_ouija)                             | <sub>Kieran Campbell <a href='https://github.com/kieranrcampbell'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Christopher Yau <a href='https://orcid.org/0000-0001-7615-8523'><img src='man/figures/orcid_logo.svg' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                     |
| ouijaflow           | <a href='https://doi.org/10.1101/060442'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_ouijaflow)           | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_ouijaflow)           | [![Build status](https://travis-ci.org/dynverse/ti_ouijaflow.svg?branch=master)](https://travis-ci.org/dynverse/ti_ouijaflow)                     | <sub>Kieran Campbell <a href='https://github.com/kieranrcampbell'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Christopher Yau</sub>                                                                                                                                                                                                                                                                                                                                                                                                                            |
| PAGA                | <a href='https://doi.org/10.1186/s13059-019-1663-x'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_paga)                | [![Version](https://img.shields.io/badge/Docker-v0.9.9.05-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_paga)                | [![Build status](https://travis-ci.org/dynverse/ti_paga.svg?branch=master)](https://travis-ci.org/dynverse/ti_paga)                               | <sub>Alexander Wolf <a href='https://orcid.org/0000-0002-8760-7838'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/falexwolf'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Fabian Theis <a href='https://github.com/theislab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                 |
| PAGA Tree           | <a href='https://doi.org/10.1186/s13059-019-1663-x'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_paga_tree)           | [![Version](https://img.shields.io/badge/Docker-v0.9.9.06-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_paga_tree)           | [![Build status](https://travis-ci.org/dynverse/ti_paga_tree.svg?branch=master)](https://travis-ci.org/dynverse/ti_paga_tree)                     | <sub>Alexander Wolf <a href='https://orcid.org/0000-0002-8760-7838'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/falexwolf'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Fabian Theis <a href='https://github.com/theislab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                 |
| pCreode             | <a href='https://doi.org/10.1016/j.cels.2017.10.012'><img src='man/figures/doi_logo.png' height='16'></a>       | [code](https://github.com/dynverse/ti_pcreode)             | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_pcreode)             | [![Build status](https://travis-ci.org/dynverse/ti_pcreode.svg?branch=master)](https://travis-ci.org/dynverse/ti_pcreode)                         | <sub>Charles A. Herring <a href='https://github.com/herrinca'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Ken S. Lau <a href='https://github.com/KenLauLab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                      |
| Periodic PrinCurve  |                                                                                                                 | [code](https://github.com/dynverse/ti_periodpc)            | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_periodpc)            | [![Build status](https://travis-ci.org/dynverse/ti_periodpc.svg?branch=master)](https://travis-ci.org/dynverse/ti_periodpc)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| PhenoPath           | <a href='https://doi.org/10.1101/159913'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_phenopath)           | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_phenopath)           | [![Build status](https://travis-ci.org/dynverse/ti_phenopath.svg?branch=master)](https://travis-ci.org/dynverse/ti_phenopath)                     | <sub>Kieran Campbell <a href='https://github.com/kieranrcampbell'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Christopher Yau <a href='https://orcid.org/0000-0001-7615-8523'><img src='man/figures/orcid_logo.svg' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                     |
| Projected DPT       |                                                                                                                 | [code](https://github.com/dynverse/ti_projected_dpt)       | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_projected_dpt)       | [![Build status](https://travis-ci.org/dynverse/ti_projected_dpt.svg?branch=master)](https://travis-ci.org/dynverse/ti_projected_dpt)             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| Projected Monocle   |                                                                                                                 | [code](https://github.com/dynverse/ti_projected_monocle)   | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_projected_monocle)   | [![Build status](https://travis-ci.org/dynverse/ti_projected_monocle.svg?branch=master)](https://travis-ci.org/dynverse/ti_projected_monocle)     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| Projected PAGA      | <a href='https://doi.org/10.1101/208819'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_projected_paga)      | [![Version](https://img.shields.io/badge/Docker-v0.9.9.05-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_projected_paga)      | [![Build status](https://travis-ci.org/dynverse/ti_projected_paga.svg?branch=master)](https://travis-ci.org/dynverse/ti_projected_paga)           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| Projected Slingshot | <a href='https://doi.org/10.1186/s12864-018-4772-0'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_projected_slingshot) | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_projected_slingshot) | [![Build status](https://travis-ci.org/dynverse/ti_projected_slingshot.svg?branch=master)](https://travis-ci.org/dynverse/ti_projected_slingshot) |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| Projected TSCAN     |                                                                                                                 | [code](https://github.com/dynverse/ti_projected_tscan)     | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_projected_tscan)     | [![Build status](https://travis-ci.org/dynverse/ti_projected_tscan.svg?branch=master)](https://travis-ci.org/dynverse/ti_projected_tscan)         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| pseudogp            | <a href='https://doi.org/10.1371/journal.pcbi.1005212'><img src='man/figures/doi_logo.png' height='16'></a>     | [code](https://github.com/dynverse/ti_pseudogp)            | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_pseudogp)            | [![Build status](https://travis-ci.org/dynverse/ti_pseudogp.svg?branch=master)](https://travis-ci.org/dynverse/ti_pseudogp)                       | <sub>Kieran Campbell <a href='https://github.com/kieranrcampbell'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Christopher Yau <a href='https://orcid.org/0000-0001-7615-8523'><img src='man/figures/orcid_logo.svg' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                     |
| RaceID / StemID     | <a href='https://doi.org/10.1016/j.stem.2016.05.010'><img src='man/figures/doi_logo.png' height='16'></a>       | [code](https://github.com/dynverse/ti_raceid_stemid)       | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_raceid_stemid)       | [![Build status](https://travis-ci.org/dynverse/ti_raceid_stemid.svg?branch=master)](https://travis-ci.org/dynverse/ti_raceid_stemid)             | <sub>Dominic Grün <a href='https://github.com/dgrun'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Alexander van Oudenaarden <a href='https://github.com/avolab'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                   |
| reCAT               | <a href='https://doi.org/10.1038/s41467-017-00039-z'><img src='man/figures/doi_logo.png' height='16'></a>       | [code](https://github.com/dynverse/ti_recat)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_recat)               | [![Build status](https://travis-ci.org/dynverse/ti_recat.svg?branch=master)](https://travis-ci.org/dynverse/ti_recat)                             | <sub>Riu Jian <a href='https://github.com/louhzmaki'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| SCIMITAR            | <a href='https://doi.org/10.1142/9789813207813_0053'><img src='man/figures/doi_logo.png' height='16'></a>       | [code](https://github.com/dynverse/ti_scimitar)            | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_scimitar)            | [![Build status](https://travis-ci.org/dynverse/ti_scimitar.svg?branch=master)](https://travis-ci.org/dynverse/ti_scimitar)                       | <sub>Josh Stuart <a href='https://github.com/dimenwarper'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| SCORPIUS            | <a href='https://doi.org/10.1101/079509'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_scorpius)            | [![Version](https://img.shields.io/badge/Docker-v1.0.0.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_scorpius)            | [![Build status](https://travis-ci.org/dynverse/ti_scorpius.svg?branch=master)](https://travis-ci.org/dynverse/ti_scorpius)                       | <sub>Robrecht Cannoodt <a href='https://orcid.org/0000-0003-3641-729X'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/rcannood'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Wouter Saelens <a href='https://orcid.org/0000-0002-7114-6248'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/zouter'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Yvan Saeys <a href='https://github.com/saeyslab'><img src='man/figures/github_logo.png' height='16'></a></sub> |
| SCOUP               | <a href='https://doi.org/10.1186/s12859-016-1109-3'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_scoup)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_scoup)               | [![Build status](https://travis-ci.org/dynverse/ti_scoup.svg?branch=master)](https://travis-ci.org/dynverse/ti_scoup)                             | <sub>Hirotaka Matsumoto <a href='https://github.com/hmatsu1226'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| SCUBA               | <a href='https://doi.org/10.1073/pnas.1408993111'><img src='man/figures/doi_logo.png' height='16'></a>          | [code](https://github.com/dynverse/ti_scuba)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_scuba)               | [![Build status](https://travis-ci.org/dynverse/ti_scuba.svg?branch=master)](https://travis-ci.org/dynverse/ti_scuba)                             | <sub>Eugenio Marco <a href='https://github.com/eugeniomarco'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Gregory Giecold <a href='https://github.com/GGiecold'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Guo-Cheng Yuan <a href='https://orcid.org/0000-0002-2283-4714'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/gcyuan'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                   |
| Sincell             | <a href='https://doi.org/10.1093/bioinformatics/btv368'><img src='man/figures/doi_logo.png' height='16'></a>    | [code](https://github.com/dynverse/ti_sincell)             | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_sincell)             | [![Build status](https://travis-ci.org/dynverse/ti_sincell.svg?branch=master)](https://travis-ci.org/dynverse/ti_sincell)                         | <sub>Antonio Rausell <a href='https://github.com/Cortalak'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Miguel Julia</sub>                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| SLICE               | <a href='https://doi.org/10.1093/nar/gkw1278'><img src='man/figures/doi_logo.png' height='16'></a>              | [code](https://github.com/dynverse/ti_slice)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_slice)               | [![Build status](https://travis-ci.org/dynverse/ti_slice.svg?branch=master)](https://travis-ci.org/dynverse/ti_slice)                             | <sub>Yan Xu <a href='https://github.com/xu-lab'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Minzhe Guo <a href='https://github.com/minzheguo'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                    |
| SLICER              | <a href='https://doi.org/10.1186/s13059-016-0975-3'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_slicer)              | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_slicer)              | [![Build status](https://travis-ci.org/dynverse/ti_slicer.svg?branch=master)](https://travis-ci.org/dynverse/ti_slicer)                           | <sub>Joshua Welch <a href='https://github.com/jw156605'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Jan Prins</sub>                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| Slingshot           | <a href='https://doi.org/10.1186/s12864-018-4772-0'><img src='man/figures/doi_logo.png' height='16'></a>        | [code](https://github.com/dynverse/ti_slingshot)           | [![Version](https://img.shields.io/badge/Docker-vc\(1,%200,%203\)-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_slingshot)   | [![Build status](https://travis-ci.org/dynverse/ti_slingshot.svg?branch=master)](https://travis-ci.org/dynverse/ti_slingshot)                     | <sub>Kelly Street <a href='https://github.com/kstreet13'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Sandrine Dudoit <a href='https://orcid.org/0000-0002-6069-8629'><img src='man/figures/orcid_logo.svg' height='16'></a> <a href='https://github.com/sandrinedudoit'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                          |
| STEMNET             | <a href='https://doi.org/10.1038/ncb3493'><img src='man/figures/doi_logo.png' height='16'></a>                  | [code](https://github.com/dynverse/ti_stemnet)             | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_stemnet)             | [![Build status](https://travis-ci.org/dynverse/ti_stemnet.svg?branch=master)](https://travis-ci.org/dynverse/ti_stemnet)                         | <sub>Lars Velten <a href='https://orcid.org/0000-0002-1233-5874'><img src='man/figures/orcid_logo.svg' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| topslam             | <a href='https://doi.org/10.1101/057778'><img src='man/figures/doi_logo.png' height='16'></a>                   | [code](https://github.com/dynverse/ti_topslam)             | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_topslam)             | [![Build status](https://travis-ci.org/dynverse/ti_topslam.svg?branch=master)](https://travis-ci.org/dynverse/ti_topslam)                         | <sub>Max Zwiessele <a href='https://github.com/mzwiessele'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
| TSCAN               | <a href='https://doi.org/10.1093/nar/gkw430'><img src='man/figures/doi_logo.png' height='16'></a>               | [code](https://github.com/dynverse/ti_tscan)               | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_tscan)               | [![Build status](https://travis-ci.org/dynverse/ti_tscan.svg?branch=master)](https://travis-ci.org/dynverse/ti_tscan)                             | <sub>Zhicheng Ji <a href='https://github.com/zji90'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Hongkai Ji</sub>                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| URD                 | <a href='https://doi.org/10.1126/science.aar3131'><img src='man/figures/doi_logo.png' height='16'></a>          | [code](https://github.com/dynverse/ti_urd)                 | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_urd)                 | [![Build status](https://travis-ci.org/dynverse/ti_urd.svg?branch=master)](https://travis-ci.org/dynverse/ti_urd)                                 | <sub>Jeffrey A. Farrell <a href='https://github.com/farrellja'><img src='man/figures/github_logo.png' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| Wanderlust          | <a href='https://doi.org/10.1016/j.cell.2014.04.005'><img src='man/figures/doi_logo.png' height='16'></a>       | [code](https://github.com/dynverse/ti_wanderlust)          | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_wanderlust)          | [![Build status](https://travis-ci.org/dynverse/ti_wanderlust.svg?branch=master)](https://travis-ci.org/dynverse/ti_wanderlust)                   | <sub>Manu Setty <a href='https://github.com/ManuSetty'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Dana Pe’er <a href='https://orcid.org/0000-0002-9259-8817'><img src='man/figures/orcid_logo.svg' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                     |
| Waterfall           | <a href='https://doi.org/10.1016/j.stem.2015.07.013'><img src='man/figures/doi_logo.png' height='16'></a>       | [code](https://github.com/dynverse/ti_waterfall)           | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_waterfall)           | [![Build status](https://travis-ci.org/dynverse/ti_waterfall.svg?branch=master)](https://travis-ci.org/dynverse/ti_waterfall)                     | <sub>Jaehoon Shin</sub><br><sub>Hongjun Song</sub>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| Wishbone            | <a href='https://doi.org/10.1038/nbt.3569'><img src='man/figures/doi_logo.png' height='16'></a>                 | [code](https://github.com/dynverse/ti_wishbone)            | [![Version](https://img.shields.io/badge/Docker-v0.9.9.01-blue.svg?logo=docker)](https://hub.docker.com/r/dynverse/ti_wishbone)            | [![Build status](https://travis-ci.org/dynverse/ti_wishbone.svg?branch=master)](https://travis-ci.org/dynverse/ti_wishbone)                       | <sub>Manu Setty <a href='https://github.com/ManuSetty'><img src='man/figures/github_logo.png' height='16'></a></sub><br><sub>Dana Pe’er <a href='https://orcid.org/0000-0002-9259-8817'><img src='man/figures/orcid_logo.svg' height='16'></a></sub>                                                                                                                                                                                                                                                                                                                                     |

## Sources

We used following resources to get a (hopefully exhaustive) list of all
TI methods:

[Anthony Gitter’s
single-cell-pseudotime](https://github.com/agitter/single-cell-pseudotime)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1297423.svg)](https://doi.org/10.5281/zenodo.1297423)

[Sean Davis’
awesome-single-cell](https://github.com/seandavi/awesome-single-cell)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1294021.svg)](https://doi.org/10.5281/zenodo.1294021)

[Luke Zappia’s scRNA-tools](https://www.scrna-tools.org)
[![DOI](https://zenodo.org/badge/DOI/10.1101/206573.svg)](https://doi.org/10.1101/206573)

## New methods

Some methods are not wrapped (yet). Check out the
[issues](https://github.com/dynverse/dynmethods/issues?q=is%3Aissue+is%3Aopen+sort%3Aupdated-desc+label%3Anew_method)
for an overview

## Latest changes

Check out `news(package = "dynwrap")` or [NEWS.md](inst/NEWS.md) for a
full list of
changes.

<!-- This section gets automatically generated from inst/NEWS.md, and also generates inst/NEWS -->

### Recent changes in dynmethods 1.1.0 (unreleased)

  - MAJOR CHANGE: Add functionality to switch between R wrappers and
    container wrappers

  - MAJOR CHANGE: Add R wrappers for **SCORPIUS**

### Recent changes in dynmethods 1.0.5 (03-07-2019)

  - SMALL CHANGES: Updates for scorpius, slingshot, paga, paga\_tree and
    paga\_projected

## Dynverse dependencies

<!-- Generated by "update_dependency_graphs.R" in the main dynverse repo -->

![](man/figures/dependencies.png)
